@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #ifndef AUTOREPLACE_CONFIG_H
@@ -22,7 +17,7 @@ class Autoreplace_Config : public QWidget, public KonviSettingsPage, private Ui:
   Q_OBJECT
 
   public:
-    explicit Autoreplace_Config(QWidget* parent, const char* name=NULL);
+    explicit Autoreplace_Config(QWidget* parent, const char* name = nullptr);
     ~Autoreplace_Config() override;
 
     void saveSettings() override;
@@ -34,7 +29,7 @@ class Autoreplace_Config : public QWidget, public KonviSettingsPage, private Ui:
   Q_SIGNALS:
     void modified();
 
-  protected Q_SLOTS:
+  private Q_SLOTS:
     void entrySelected(QTreeWidgetItem* autoreplaceEntry);
     void directionChanged(int newDirection);
     void patternChanged(const QString& newPattern);
@@ -42,13 +37,15 @@ class Autoreplace_Config : public QWidget, public KonviSettingsPage, private Ui:
     void addEntry();
     void removeEntry();
 
-  protected:
+  private:
     void setAutoreplaceListView(const QList<QStringList> &autoreplaceList);
+    QList<QStringList> currentAutoreplaceList() const;
 
+  private:
     bool m_newItemSelected;
-
     QList<QStringList> m_oldAutoreplaceList;
-    QList<QStringList> currentAutoreplaceList();
+
+    Q_DISABLE_COPY(Autoreplace_Config)
 };
 
 #endif
