@@ -1,26 +1,13 @@
 /*
- *  This file is part of the KDE libraries
- *  Copyright (C) 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
- *  Copyright (C) 2003 Waldo Bastian <bastian@kde.org>
- *
- *  Forked from KConfigDialog from KF5::ConfigWidgets to add tree support.
- *  Copyright (C) 2014 Eike Hein
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2003 Benjamin C Meyer (ben+kdelibs at meyerhome dot net)
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+
+    Forked from KConfigDialog from KF5::ConfigWidgets to add tree support.
+    SPDX-FileCopyrightText: 2014 Eike Hein
+*/
+
 #ifndef CONFIGDIALOG_H
 #define CONFIGDIALOG_H
 
@@ -76,19 +63,6 @@ class ConfigDialog : public KPageDialog
 {
     Q_OBJECT
 
-Q_SIGNALS:
-    /**
-     * A widget in the dialog was modified.
-     */
-    void widgetModified();
-
-    /**
-     * One or more of the settings have been permanently changed such as if
-     * the user clicked on the Apply or Ok button.
-     * @param dialogName the name of the dialog.
-     */
-    void settingsChanged(const QString &dialogName);
-
 public:
     /**
      * @param parent - The parent of this object.  Even though the class
@@ -195,6 +169,19 @@ public:
      */
     static bool showDialog(const QString &name);
 
+Q_SIGNALS:
+    /**
+     * A widget in the dialog was modified.
+     */
+    void widgetModified();
+
+    /**
+     * One or more of the settings have been permanently changed such as if
+     * the user clicked on the Apply or Ok button.
+     * @param dialogName the name of the dialog.
+     */
+    void settingsChanged(const QString &dialogName);
+
 protected Q_SLOTS:
     /**
      * Update the settings from the dialog.
@@ -294,9 +281,6 @@ private:
 
     ConfigDialogPrivate *const d;
 
-    Q_PRIVATE_SLOT(d, void _k_updateButtons())
-    Q_PRIVATE_SLOT(d, void _k_settingsChangedSlot())
-
     Q_DISABLE_COPY(ConfigDialog)
 };
 
