@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2017 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2017 Peter Simonsson <peter.simonsson@gmail.com>
 */
 
 #ifndef HIGHLIGHTTREEWIDGET_H
@@ -21,11 +16,11 @@ class HighlightTreeWidget : public QTreeWidget
     public:
         HighlightTreeWidget(QWidget *parent = nullptr);
 
+    Q_SIGNALS:
+        void itemDropped();
+
     protected:
         void dropEvent(QDropEvent *event) override;
-
-    signals:
-        void itemDropped();
 };
 
 #endif // HIGHLIGHTTREEWIDGET_H
