@@ -18,7 +18,7 @@ class Ignore_Config : public QWidget, public KonviSettingsPage, private Ui::Igno
 
     public:
         explicit Ignore_Config( QWidget* parent = nullptr, const char* name = nullptr, Qt::WindowFlags fl = {} );
-        ~Ignore_Config();
+        ~Ignore_Config() override;
 
         void restorePageToDefaults() override;
         void saveSettings() override;
