@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004 Peter Simonsson <psn@linux.se>
-  Copyright (C) 2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
+    SPDX-FileCopyrightText: 2008 Eike Hein <hein@kde.org>
 */
 
 #include "serversettings.h"
@@ -23,14 +18,8 @@ namespace Konversation
         setBypassProxy(false);
     }
 
-    ServerSettings::ServerSettings(const ServerSettings& settings)
-    {
-        setHost(settings.host());
-        setPort(settings.port());
-        setPassword(settings.password());
-        setSSLEnabled(settings.SSLEnabled());
-        setBypassProxy(settings.bypassProxy());
-    }
+    ServerSettings::ServerSettings(const ServerSettings& /*settings*/) = default;
+    ServerSettings &ServerSettings::operator=(const ServerSettings& /*settings*/) = default;
 
     ServerSettings::ServerSettings(const QString& host)
     {
