@@ -1,14 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Wed Sep 1 2004
-  copyright: (C) 2004 by Gary Cramblitt
-  email:     garycramblitt@comcast.net
+    SPDX-FileCopyrightText: 2004 Gary Cramblitt <garycramblitt@comcast.net>
 */
 
 #ifndef EDITNOTIFYDIALOG_H
@@ -33,21 +26,25 @@ class EditNotifyDialog : public QDialog
     Q_OBJECT
 
     public:
-        explicit EditNotifyDialog(QWidget* parent=0, int serverGroupId=0,
+        explicit EditNotifyDialog(QWidget* parent = nullptr, int serverGroupId = 0,
             const QString& nickname=QString());
         ~EditNotifyDialog() override;
 
         Q_SIGNALS:
         void notifyChanged(int serverGroupId,
             const QString& nickname);
-    protected Q_SLOTS:
-        void slotOk();
 
-    protected:
-        KComboBox* m_networkNameCombo;
-        KLineEdit* m_nicknameInput;
+    private Q_SLOTS:
+        void slotOk();
 
     private:
         void delayedDestruct();
+
+    private:
+        KComboBox* m_networkNameCombo;
+        KLineEdit* m_nicknameInput;
+
+        Q_DISABLE_COPY(EditNotifyDialog)
 };
+
 #endif
