@@ -72,7 +72,12 @@ QString Highlight::getAutoText() const
 
 void Highlight::setSoundURL(const QUrl &url)
 {
-    m_soundURL = url;
+    if (url.isLocalFile()) {
+        m_soundURL = url;
+    } else {
+        // A highlight entry in an old config doesn't have a "file://" prefix
+        m_soundURL = QUrl::fromLocalFile(url.toString());
+    }
 }
 
 QUrl Highlight::getSoundURL() const
@@ -85,11 +90,7 @@ void Highlight::setChatWindows(const QString& chatWindows)
     m_chatWindows = chatWindows;
 
     // split string list of chat windows and trim all entries
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    m_chatWindowList = m_chatWindows.split(QRegularExpression(QStringLiteral("[,;]")), QString::SkipEmptyParts);
-#else
     m_chatWindowList = m_chatWindows.split(QRegularExpression(QStringLiteral("[,;]")), Qt::SkipEmptyParts);
-#endif
 
     for (QString& chatWindow : m_chatWindowList) {
         chatWindow = chatWindow.trimmed();
