@@ -1,17 +1,8 @@
-/***************************************************************************
-    begin                : Sat Jun 15 2002
-    copyright            : (C) 2002 by Matthias Gierlings
-    email                : gismore@users.sourceforge.net
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Matthias Gierlings <gismore@users.sourceforge.net>
+*/
 
 #ifndef HIGHLIGHTVIEWITEM_H
 #define HIGHLIGHTVIEWITEM_H
@@ -53,7 +44,7 @@ class HighlightViewItem : public QTreeWidgetItem
         void setNotify(bool doNotify);
         bool getNotify() const;
 
-    protected:
+    private:
         int m_itemID;
 
         QString m_pattern;
@@ -62,5 +53,7 @@ class HighlightViewItem : public QTreeWidgetItem
         QString m_autoText;
         QString m_chatWindows;
         bool m_notify;
+
+        Q_DISABLE_COPY(HighlightViewItem)
 };
 #endif
