@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Shows the content of a log file
-  begin:     Fri Dec 5 2003
-  copyright: (C) 2003 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2003 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef LOGFILEREADER_H
@@ -23,7 +15,9 @@ class QSpinBox;
 
 class KToolBar;
 
-
+/**
+ * Shows the content of a log file
+ */
 class LogfileReader : public ChatWindow
 {
     Q_OBJECT
@@ -34,12 +28,15 @@ class LogfileReader : public ChatWindow
 
         using ChatWindow::closeYourself;
         virtual bool closeYourself() { closeLog(); return true; }
-        bool searchView() override;
+        bool searchView() const override;
 
         bool eventFilter(QObject* watched, QEvent* e) override;
 
+    protected:
+        /** Called from ChatWindow adjustFocus */
+        void childAdjustFocus() override;
 
-    protected Q_SLOTS:
+    private Q_SLOTS:
         void updateView();
         void storeBufferSize(int kb);
         void clearLog();
@@ -47,16 +44,12 @@ class LogfileReader : public ChatWindow
         void closeLog();
         void copyResult(KJob* job);
 
-
-    protected:
-        int margin();
-        int spacing();
-
-        /** Called from ChatWindow adjustFocus */
-        void childAdjustFocus() override;
-
+    private:
         KToolBar* toolBar;
         QSpinBox* sizeSpin;
         QString fileName;
+
+        Q_DISABLE_COPY(LogfileReader)
 };
+
 #endif
