@@ -79,9 +79,7 @@ class TopicHistoryItemDelegate : public KWidgetItemDelegate
 
     protected:
         QList<QWidget*> createItemWidgets (const QModelIndex& index) const override;
-        void updateItemWidgets(const QList<QWidget*> widgets, const QStyleOptionViewItem& option,
-            const QPersistentModelIndex& index) const override;
-
+        void updateItemWidgets(const QList<QWidget *> &widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const override;
 
     private:
         TopicHistoryLabel* m_hiddenLabel;
